import express from 'express';
import * as http from 'http';
import * as bodyparser from 'body-parser';
import * as dotenv from 'dotenv';

dotenv.config();

if (!process.env.PORT) {
    console.log('No port');
    process.exit(1);
}

const port: number = parseInt(process.env.PORT, 10);

// DHBW Service
import {generalInfoRouter} from "./src/models/dhbw-service/GeneralInfo.router";

// Twitch Highlight Marker
import {addHighlightRouter} from "./src/models/twitch-highlight-marker/AddHighlight.router";

const app: express.Application = express();
const server: http.Server = http.createServer(app);

// here we are adding middleware to parse all incoming requests as JSON
app.use(bodyparser.json());

// Add routers
app.use('/dhbw-service/generalInfo', generalInfoRouter);
app.use('/twitch-highlight-marker/addHighlight', addHighlightRouter);

// this is a simple route to make sure everything is working properly
app.get('/', (req: express.Request, res: express.Response) => {
    res.status(200).send('Welcome to the Pluto Development REST API V2!');
});

server.listen(port, () => {
    console.log('Server listening on Port ' + port);
});
